@@ -92,6 +92,8 @@ class Call:
         channel[CHANNEL_INTERFACE].connect_to_signal('Closed', self.closed_cb)
         channel[CHANNEL_INTERFACE_GROUP].connect_to_signal('MembersChanged',
             self.members_changed_cb)
+        channel[CHANNEL_TYPE_STREAMED_MEDIA].connect_to_signal(
+            'StreamError', self.stream_error_cb)
 
         stream_engine = get_stream_engine()
         handler = dbus.Interface(stream_engine,
@@ -106,6 +108,10 @@ class Call:
 
         self.channel = channel
 
+    def stream_error_cb(self, *foo):
+        print 'error: %r' % (foo,)
+        self.channel.close()
+
     def closed_cb(self):
         print "channel closed"
         self.quit()
@@ -172,13 +178,16 @@ class IncomingCall(Call):
         pending = channel[CHANNEL_INTERFACE_GROUP].GetLocalPendingMembers()
         channel[CHANNEL_INTERFACE_GROUP].AddMembers(pending, "")
 
+    def closed_cb(self):
+        print "channel closed"
+        print "waiting for incoming call"
+
 if __name__ == '__main__':
     args = sys.argv[1:]
 
     assert len(args) in (1, 2)
 
     if len(args) > 1:
-        contact = args[1]
         call = OutgoingCall(args[0], args[1])
     else:
         call = IncomingCall(args[0])
