@@ -32,10 +32,7 @@ from telepathy.interfaces import (CONN_INTERFACE,
                                   CONN_INTERFACE_ALIASING,
                                   CONN_INTERFACE_AVATARS,
                                   CONN_INTERFACE_CAPABILITIES,
-                                  CONN_INTERFACE_CONTACT_INFO,
-                                  CONN_INTERFACE_FORWARDING,
                                   CONN_INTERFACE_PRESENCE,
-                                  CONN_INTERFACE_PRIVACY,
                                   CONN_INTERFACE_RENAMING)
 from telepathy.server.handle import Handle
 
@@ -339,60 +336,14 @@ class ConnectionInterfaceCapabilities(_ConnectionInterfaceCapabilities):
         return [(ctype, caps[1]) for ctype, caps in my_caps.iteritems()]
 
 
-from telepathy._generated.Connection_Interface_Contact_Info \
-        import ConnectionInterfaceContactInfo
-
-
-from telepathy._generated.Connection_Interface_Forwarding \
-        import ConnectionInterfaceForwarding \
-        as _ConnectionInterfaceForwarding
-
-class ConnectionInterfaceForwarding(_ConnectionInterfaceForwarding):
-    def __init__(self):
-        _ConnectionInterfaceForwarding.__init__(self)
-        self._forwarding_handle = 0
-
-    @dbus.service.method(CONN_INTERFACE_FORWARDING, in_signature='', out_signature='u')
-    def GetForwardingHandle(self):
-        return self._forwarding_handle
-
-    @dbus.service.signal(CONN_INTERFACE_FORWARDING, signature='u')
-    def ForwardingChanged(self, forward_to):
-        self._forwarding_handle = forward_to
-
-
 from telepathy._generated.Connection_Interface_Presence \
         import ConnectionInterfacePresence
 
-
-from telepathy._generated.Connection_Interface_Privacy \
-        import ConnectionInterfacePrivacy \
-        as _ConnectionInterfacePrivacy
-
-class ConnectionInterfacePrivacy(_ConnectionInterfacePrivacy):
-    def __init__(self, modes):
-        """
-        Initialise privacy interface.
-
-        Parameters:
-        modes - a list of privacy modes available on this interface
-        """
-        _ConnectionInterfacePrivacy.__init__(self)
-        self._privacy_mode = ''
-        self._privacy_modes = modes
-
-    @dbus.service.method(CONN_INTERFACE_PRIVACY, in_signature='', out_signature='as')
-    def GetPrivacyModes(self):
-        return self._privacy_modes
-
-    @dbus.service.method(CONN_INTERFACE_PRIVACY, in_signature='', out_signature='s')
-    def GetPrivacyMode(self):
-        return self._privacy_mode
-
-    @dbus.service.signal(CONN_INTERFACE_PRIVACY, signature='s')
-    def PrivacyModeChanged(self, mode):
-        self._privacy_mode = mode
-
-
 from telepathy._generated.Connection_Interface_Renaming \
         import ConnectionInterfaceRenaming
+
+from telepathy._generated.Connection_Interface_Simple_Presence \
+        import ConnectionInterfaceSimplePresence
+
+from telepathy._generated.Connection_Interface_Contacts \
+        import ConnectionInterfaceContacts
